meta_package_manager.tests.test_bitbar_plugin module
====================================================

.. automodule:: meta_package_manager.tests.test_bitbar_plugin
    :members:
    :undoc-members:
    :show-inheritance:
